package com.logicbig.example;


import javax.swing.*;
import java.awt.*;
import java.util.List;

public class JListHighlightedFilterExample {
    public static void main(String[] args) {
        List<Employee> employees = EmployeeDataAccess.getEmployees();
        DefaultListModel<Employee> model = new DefaultListModel<>();
        employees.forEach(model::addElement);
        JList<Employee> jList = new JList<>(model);
        JListFilterDecorator decorator = JListFilterDecorator
                .decorate(jList, JListHighlightedFilterExample::employeeFilter);
        jList.setCellRenderer(createListRenderer(decorator.getFilterField()));

        JFrame frame = createFrame();
        frame.add(decorator.getContentPanel());
        frame.setLocationRelativeTo(null);
        frame.setVisible(true);
    }

    private static boolean employeeFilter(Employee emp, String str) {
        return getEmployeeDisplayText(emp).toLowerCase().contains(str.toLowerCase());
    }

    private static String getEmployeeDisplayText(Employee emp) {
        return String.format("%s [%s]", emp.getName(), emp.getDept());
    }

    private static ListCellRenderer<? super Employee> createListRenderer(JTextField filterField) {
        return new DefaultListCellRenderer() {
            private Color background = new Color(0, 100, 255, 15);
            private Color defaultBackground = (Color) UIManager.get("List.background");

            @Override
            public Component getListCellRendererComponent(JList<?> list, Object value, int index,
                                                          boolean isSelected, boolean cellHasFocus) {
                Component c = super.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);

                if (c instanceof JLabel) {
                    Employee emp = (Employee) value;
                    JLabel original = (JLabel) c;
                    LabelHighlighted label = new LabelHighlighted();
                    label.setText(getEmployeeDisplayText(emp));
                    label.setFont(original.getFont().deriveFont(14f).deriveFont(Font.PLAIN));
                    label.setBackground(original.getBackground());
                    label.setForeground(original.getForeground());
                    label.setOpaque(original.isOpaque());
                    label.setHorizontalTextPosition(original.getHorizontalTextPosition());
                    label.highlightText(filterField.getText());
                    return label;
                }
                return c;
            }
        };
    }

    private static JFrame createFrame() {
        JFrame frame = new JFrame("JList Example");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.setSize(new Dimension(600, 300));
        return frame;
    }
}